==> qtjambi-datavisualization-5.15.6-sources.jar: io/qt/datavis/QScatterDataProxy.java <==
package io.qt.datavis;


/**
 * <p>The data proxy for 3D scatter graphs</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html">QtDataVisualization::QScatterDataProxy</a></p>
 */
public class QScatterDataProxy extends io.qt.datavis.QAbstractDataProxy
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScatterDataProxy.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#arrayReset">QtDataVisualization::QScatterDataProxy::arrayReset()</a></p>
     */
    public final Signal0 arrayReset = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemCount-prop">QtDataVisualization::QScatterDataProxy::itemCountChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="itemCount")
    public final Signal1<@io.qt.QtPrimitiveType Integer> itemCountChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsAdded">QtDataVisualization::QScatterDataProxy::itemsAdded(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsAdded = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsChanged">QtDataVisualization::QScatterDataProxy::itemsChanged(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsChanged = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsInserted">QtDataVisualization::QScatterDataProxy::itemsInserted(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsInserted = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsRemoved">QtDataVisualization::QScatterDataProxy::itemsRemoved(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsRemoved = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#series-prop">QtDataVisualization::QScatterDataProxy::seriesChanged(QtDataVisualization::QScatter3DSeries*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="series")
    public final Signal1<io.qt.datavis.QScatter3DSeries> seriesChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QScatterDataProxy(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScatterDataProxy() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#QScatterDataProxy">QtDataVisualization::QScatterDataProxy::QScatterDataProxy(QObject*)</a></p>
     */
    public QScatterDataProxy(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QScatterDataProxy instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#addItem">QtDataVisualization::QScatterDataProxy::addItem(QtDataVisualization::QScatterDataItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final int addItem(io.qt.datavis.QScatterDataItem item){
        return addItem_native_cref_QtDataVisualization_QScatterDataItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native int addItem_native_cref_QtDataVisualization_QScatterDataItem(long __this__nativeId, long item);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#addItems">QtDataVisualization::QScatterDataProxy::addItems(QtDataVisualization::QScatterDataArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final int addItems(io.qt.datavis.QScatterDataArray items){
        return addItems_native_cref_QtDataVisualization_QScatterDataArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(items));
    }
    
    @io.qt.QtUninvokable
    private native int addItems_native_cref_QtDataVisualization_QScatterDataArray(long __this__nativeId, long items);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#array">QtDataVisualization::QScatterDataProxy::array()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.datavis.QScatterDataArray array(){
        return array_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QScatterDataArray array_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#insertItem">QtDataVisualization::QScatterDataProxy::insertItem(int,QtDataVisualization::QScatterDataItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insertItem(int index, io.qt.datavis.QScatterDataItem item){
        insertItem_native_int_cref_QtDataVisualization_QScatterDataItem(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void insertItem_native_int_cref_QtDataVisualization_QScatterDataItem(long __this__nativeId, int index, long item);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#insertItems">QtDataVisualization::QScatterDataProxy::insertItems(int,QtDataVisualization::QScatterDataArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insertItems(int index, io.qt.datavis.QScatterDataArray items){
        insertItems_native_int_cref_QtDataVisualization_QScatterDataArray(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(items));
    }
    
    @io.qt.QtUninvokable
    private native void insertItems_native_int_cref_QtDataVisualization_QScatterDataArray(long __this__nativeId, int index, long items);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemAt">QtDataVisualization::QScatterDataProxy::itemAt(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.datavis.QScatterDataItem itemAt(int index){
        return itemAt_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QScatterDataItem itemAt_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemCount-prop">QtDataVisualization::QScatterDataProxy::itemCount()const</a></p>
     */
    @io.qt.QtPropertyReader(name="itemCount")
    @io.qt.QtUninvokable
    public final int itemCount(){
        return itemCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int itemCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#removeItems">QtDataVisualization::QScatterDataProxy::removeItems(int,int)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeItems(int index, int removeCount){
        removeItems_native_int_int(QtJambi_LibraryUtilities.internal.nativeId(this), index, removeCount);
    }
    
    @io.qt.QtUninvokable
    private native void removeItems_native_int_int(long __this__nativeId, int index, int removeCount);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#resetArray">QtDataVisualization::QScatterDataProxy::resetArray(QtDataVisualization::QScatterDataArray*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void resetArray(io.qt.datavis.QScatterDataArray newArray){
        QtJambi_LibraryUtilities.internal.invalidateObject(__rcArray);
        resetArray_native_QtDataVisualization_QScatterDataArray_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), newArray);
        QtJambi_LibraryUtilities.internal.setCppOwnership(newArray);
        __rcArray = newArray;
                    QtJambi_LibraryUtilities.internal.registerDependentObject(__rcArray, this);
    }
    
    @io.qt.QtUninvokable
    private native void resetArray_native_QtDataVisualization_QScatterDataArray_ptr(long __this__nativeId, io.qt.datavis.QScatterDataArray newArray);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#series-prop">QtDataVisualization::QScatterDataProxy::series()const</a></p>
     */
    @io.qt.QtPropertyReader(name="series")
    @io.qt.QtUninvokable
    public final io.qt.datavis.QScatter3DSeries series(){
        return series_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QScatter3DSeries series_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#setItem">QtDataVisualization::QScatterDataProxy::setItem(int,QtDataVisualization::QScatterDataItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setItem(int index, io.qt.datavis.QScatterDataItem item){
        setItem_native_int_cref_QtDataVisualization_QScatterDataItem(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void setItem_native_int_cref_QtDataVisualization_QScatterDataItem(long __this__nativeId, int index, long item);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#setItems">QtDataVisualization::QScatterDataProxy::setItems(int,QtDataVisualization::QScatterDataArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setItems(int index, io.qt.datavis.QScatterDataArray items){
        setItems_native_int_cref_QtDataVisualization_QScatterDataArray(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(items));
    }
    
    @io.qt.QtUninvokable
    private native void setItems_native_int_cref_QtDataVisualization_QScatterDataArray(long __this__nativeId, int index, long items);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScatterDataProxy(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScatterDataProxy(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScatterDataProxy instance, QDeclarativeConstructor constructor);
    
    private QScatterDataArray __rcArray;
}

==> qtjambi-datavisualization-5.15.11-sources.jar: io/qt/datavis/QScatterDataProxy.java <==
package io.qt.datavis;


/**
 * <p>The data proxy for 3D scatter graphs</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html">QtDataVisualization::QScatterDataProxy</a></p>
 */
public class QScatterDataProxy extends io.qt.datavis.QAbstractDataProxy
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScatterDataProxy.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#arrayReset">QtDataVisualization::QScatterDataProxy::arrayReset()</a></p>
     */
    public final Signal0 arrayReset = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemCount-prop">QtDataVisualization::QScatterDataProxy::itemCountChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="itemCount")
    public final Signal1<@io.qt.QtPrimitiveType Integer> itemCountChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsAdded">QtDataVisualization::QScatterDataProxy::itemsAdded(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsAdded = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsChanged">QtDataVisualization::QScatterDataProxy::itemsChanged(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsChanged = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsInserted">QtDataVisualization::QScatterDataProxy::itemsInserted(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsInserted = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemsRemoved">QtDataVisualization::QScatterDataProxy::itemsRemoved(int,int)</a></p>
     */
    public final Signal2<@io.qt.QtPrimitiveType Integer, @io.qt.QtPrimitiveType Integer> itemsRemoved = new Signal2<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#series-prop">QtDataVisualization::QScatterDataProxy::seriesChanged(QtDataVisualization::QScatter3DSeries*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="series")
    public final Signal1<io.qt.datavis.QScatter3DSeries> seriesChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QScatterDataProxy(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScatterDataProxy() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#QScatterDataProxy">QtDataVisualization::QScatterDataProxy::QScatterDataProxy(QObject*)</a></p>
     */
    public QScatterDataProxy(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QScatterDataProxy instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#addItem">QtDataVisualization::QScatterDataProxy::addItem(QtDataVisualization::QScatterDataItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final int addItem(io.qt.datavis.QScatterDataItem item){
        return addItem_native_cref_QtDataVisualization_QScatterDataItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native int addItem_native_cref_QtDataVisualization_QScatterDataItem(long __this__nativeId, long item);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#addItems">QtDataVisualization::QScatterDataProxy::addItems(QtDataVisualization::QScatterDataArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final int addItems(io.qt.datavis.QScatterDataArray items){
        return addItems_native_cref_QtDataVisualization_QScatterDataArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(items));
    }
    
    @io.qt.QtUninvokable
    private native int addItems_native_cref_QtDataVisualization_QScatterDataArray(long __this__nativeId, long items);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#array">QtDataVisualization::QScatterDataProxy::array()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.datavis.QScatterDataArray array(){
        return array_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QScatterDataArray array_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#insertItem">QtDataVisualization::QScatterDataProxy::insertItem(int,QtDataVisualization::QScatterDataItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insertItem(int index, io.qt.datavis.QScatterDataItem item){
        insertItem_native_int_cref_QtDataVisualization_QScatterDataItem(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void insertItem_native_int_cref_QtDataVisualization_QScatterDataItem(long __this__nativeId, int index, long item);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#insertItems">QtDataVisualization::QScatterDataProxy::insertItems(int,QtDataVisualization::QScatterDataArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insertItems(int index, io.qt.datavis.QScatterDataArray items){
        insertItems_native_int_cref_QtDataVisualization_QScatterDataArray(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(items));
    }
    
    @io.qt.QtUninvokable
    private native void insertItems_native_int_cref_QtDataVisualization_QScatterDataArray(long __this__nativeId, int index, long items);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemAt">QtDataVisualization::QScatterDataProxy::itemAt(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.datavis.QScatterDataItem itemAt(int index){
        return itemAt_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QScatterDataItem itemAt_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#itemCount-prop">QtDataVisualization::QScatterDataProxy::itemCount()const</a></p>
     */
    @io.qt.QtPropertyReader(name="itemCount")
    @io.qt.QtUninvokable
    public final int itemCount(){
        return itemCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int itemCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#removeItems">QtDataVisualization::QScatterDataProxy::removeItems(int,int)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeItems(int index, int removeCount){
        removeItems_native_int_int(QtJambi_LibraryUtilities.internal.nativeId(this), index, removeCount);
    }
    
    @io.qt.QtUninvokable
    private native void removeItems_native_int_int(long __this__nativeId, int index, int removeCount);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#resetArray">QtDataVisualization::QScatterDataProxy::resetArray(QtDataVisualization::QScatterDataArray*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void resetArray(io.qt.datavis.QScatterDataArray newArray){
        QtJambi_LibraryUtilities.internal.invalidateObject(__rcArray);
        resetArray_native_QtDataVisualization_QScatterDataArray_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), newArray);
        QtJambi_LibraryUtilities.internal.setCppOwnership(newArray);
        __rcArray = newArray;
                    QtJambi_LibraryUtilities.internal.registerDependentObject(__rcArray, this);
    }
    
    @io.qt.QtUninvokable
    private native void resetArray_native_QtDataVisualization_QScatterDataArray_ptr(long __this__nativeId, io.qt.datavis.QScatterDataArray newArray);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#series-prop">QtDataVisualization::QScatterDataProxy::series()const</a></p>
     */
    @io.qt.QtPropertyReader(name="series")
    @io.qt.QtUninvokable
    public final io.qt.datavis.QScatter3DSeries series(){
        return series_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QScatter3DSeries series_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#setItem">QtDataVisualization::QScatterDataProxy::setItem(int,QtDataVisualization::QScatterDataItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setItem(int index, io.qt.datavis.QScatterDataItem item){
        setItem_native_int_cref_QtDataVisualization_QScatterDataItem(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void setItem_native_int_cref_QtDataVisualization_QScatterDataItem(long __this__nativeId, int index, long item);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscatterdataproxy.html#setItems">QtDataVisualization::QScatterDataProxy::setItems(int,QtDataVisualization::QScatterDataArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setItems(int index, io.qt.datavis.QScatterDataArray items){
        setItems_native_int_cref_QtDataVisualization_QScatterDataArray(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(items));
    }
    
    @io.qt.QtUninvokable
    private native void setItems_native_int_cref_QtDataVisualization_QScatterDataArray(long __this__nativeId, int index, long items);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScatterDataProxy(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScatterDataProxy(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScatterDataProxy instance, QDeclarativeConstructor constructor);
    
    private QScatterDataArray __rcArray;
}
